.statistics-dashboard{background-color:rgba(0,0,0,.2);padding:.7rem .9rem .9rem .9rem;border-radius:.4rem}.models-dashboard{flex-wrap:wrap;gap:.6rem}.models-dashboard>div{background-color:rgba(0,0,0,.2);padding:.7rem .9rem .9rem .9rem;border-radius:.4rem;height:min-content}.models-dashboard>div>h5{font-size:1.5rem;font-weight:bold;margin-bottom:.7rem}.models-dashboard>div a{font-size:1.2rem;font-weight:500}.models-dashboard .model-link{transition:all 300ms ease-in-out;text-decoration:none;background-color:hsla(0,0%,100%,.0666666667);display:flex;justify-content:center;align-items:center;border-radius:.3rem;width:min-content;white-space:nowrap;padding:.1rem .4rem}.models-dashboard .model-link:hover{color:#fff !important;background-color:rgba(80,154,255,.49)}.select2-selection__choice{background-color:rgba(0,0,0,.2) !important;color:#fff;border-radius:.3rem;padding-right:.5rem !important}.select2-selection__choice .select2-selection__choice__remove{padding-right:4px !important;margin-right:.4rem !important}.select2-selection__choice:hover{background-color:rgba(80,154,255,.49)}#result_list select{border-radius:.3rem;padding:.1rem .3rem .2rem .3rem}.object-tools{margin-bottom:0}
