@import url("https://fonts.googleapis.com/css2?family=Nunito:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;0,1000;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900;1,1000&display=swap");
body {
  font-size: 16px;
  font-family: "Nunito", sans-serif !important;
}

.xl-dashboard ul, .xl-dashboard li {
  list-style-type: none;
  padding: 0;
}
.xl-dashboard li {
  border-radius: 7px;
}

#jazzy-navbar {
  margin-left: 0 !important;
}

input[type=checkbox] {
  transform: scale(1.5);
}

.related-widget-wrapper button {
  background: rgba(0, 0, 0, 0.1333333333);
  border: 0;
  border-radius: 8px;
}

.statistics-dashboard {
  background-color: rgba(0, 0, 0, 0.2);
  padding: 0.7rem 0.9rem 0.9rem 0.9rem;
  border-radius: 0.4rem;
}

.main-sidebar {
  width: 270px;
}

.sidebar-scroll {
  scrollbar-width: none;
  -ms-overflow-style: none;
  overflow: -moz-scrollbars-none;
}
.sidebar-scroll::-webkit-scrollbar {
  display: none;
  width: 0;
  height: 0;
}

.object-tools {
  padding: 0.3rem;
}

.models-dashboard {
  flex-wrap: wrap;
  gap: 0.6rem;
}
.models-dashboard > div {
  background-color: rgba(0, 0, 0, 0.2);
  padding: 0.7rem 0.9rem 0.9rem 0.9rem;
  border-radius: 0.4rem;
  height: min-content;
}
.models-dashboard > div > h5 {
  font-size: 1.5rem;
  font-weight: bold;
  margin-bottom: 0.7rem;
}
.models-dashboard > div a {
  font-size: 1.2rem;
  font-weight: 500;
}
.models-dashboard .model-link {
  transition: all 300ms ease-in-out;
  text-decoration: none;
  background-color: rgba(255, 255, 255, 0.0666666667);
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 0.3rem;
  width: min-content;
  white-space: nowrap;
  padding: 0.1rem 0.4rem;
}
.models-dashboard .model-link:hover {
  color: #fff !important;
  background-color: rgba(80, 154, 255, 0.49);
}

#result_list select {
  border-radius: 0.3rem;
  padding: 0.1rem 0.3rem 0.2rem 0.3rem;
}

.object-tools {
  margin-bottom: 0;
}

.xl-dashboard-btn-link:hover {
  color: white !important;
}

:root {
  --primary: #f1495b;
  --secondary: #444444;
  --success: #28a745;
  --info: #17a2b8;
  --warning: #ffc107;
  --danger: #dc3545;
  --light: #f8f9fa;
  --dark: #37363d !important;
}

@media (prefers-color-scheme: dark) {
  :root {
    --primary: #375a7f;
    --secondary: #444;
    --success: #00bc8c;
    --info: #3498db;
    --warning: #f39c12;
    --danger: #e74c3c;
    --light: #adb5bd;
    --dark: #303030;
  }
}
.dark-mode .card {
  background-color: #37363d !important;
}

.dark-mode .nav-tabs .nav-link.active {
  background-color: #37363d !important;
}

.form-control:not(.form-control-navbar):not(.form-control-sidebar):not(:hover) {
  background-color: #37363d !important;
  border-color: #454655 !important;
}

.dark-mode .select2-dropdown {
  background-color: #37363d !important;
}

.dark-mode .select2-dropdown .select2-search__field {
  background-color: #37363d !important;
}

.dark-mode .select2-results__option[aria-selected=true] {
  background-color: #454655 !important;
}

.django-tinymce-widget {
  filter: invert(0.9) hue-rotate(180deg);
}
.django-tinymce-widget img {
  filter: invert(1) hue-rotate(180deg);
}

.content-wrapper {
  margin-left: 0 !important;
}

.content-wrapper > .content {
  border-bottom: 0 !important;
  margin-bottom: 0 !important;
  padding-bottom: 0 !important;
}

.dark-mode .sidebar-dark-indigo .nav-sidebar > .nav-item > .nav-link.active, .dark-mode .sidebar-light-indigo .nav-sidebar > .nav-item > .nav-link.active {
  background-color: #fe586b;
  color: #fff;
}

.dark-mode .content-wrapper {
  background-color: #27262b;
  color: #fff;
}

.dark-mode .navbar-dark {
  background-color: #37363d;
  border-color: #4b545c;
}

[class*=sidebar-dark-] {
  background-color: #37363d;
}

.main-sidebar .brand-link {
  background-color: #37363d !important;
}

@media (prefers-color-scheme: dark) {
  .card-header {
    background-color: rgba(0, 0, 0, 0.2) !important;
  }
}
@media (prefers-color-scheme: dark) {
  .table-striped tbody tr:nth-of-type(odd) {
    background-color: unset !important;
  }
}
.accent-lightblue .btn-link, .accent-lightblue .nav-tabs .nav-link, .accent-lightblue a:not(.dropdown-item):not(.btn-app):not(.nav-link):not(.brand-link):not(.page-link):not(.btn) {
  color: #e7e7e7;
  transition: all 150ms ease-in-out;
}
.accent-lightblue .btn-link:hover, .accent-lightblue .nav-tabs .nav-link:hover, .accent-lightblue a:not(.dropdown-item):not(.btn-app):not(.nav-link):not(.brand-link):not(.page-link):not(.btn):hover {
  color: #bfb8ff;
  text-decoration: none;
}

.select2-container--default .select2-selection--single {
  padding-top: 10px;
  background-color: #37363d !important;
  border: 1px solid #8b8b8b !important;
  border-radius: 4px;
}

.select2-container--default .select2-selection--single .select2-selection__rendered {
  color: #c6c6c6 !important;
  line-height: 28px;
}

.select2-container--default .select2-dropdown .select2-search__field {
  border-radius: 0.4em !important;
  border: 1px solid rgba(161, 161, 161, 0.3) !important;
}

.select2-results__option {
  color: #8b8b8b;
}

.select2-container--default .select2-results__option--selected {
  background-color: #473f91 !important;
  color: #e7e7e7;
}

.select2-container--default .select2-dropdown .select2-search__field:focus, .select2-container--default .select2-search--inline .select2-search__field:focus {
  outline: 0;
  transition: all 150ms ease-in-out;
  border: 1px solid #bfb8ff;
}

.select2.select2-container.select2-container--admin-autocomplete {
  border: 2px solid rgba(255, 255, 255, 0.2666666667) !important;
  border-radius: 6px;
}

.select2-container--default .select2-selection--multiple {
  background-color: #37363d !important;
  border: 1px solid rgba(161, 161, 161, 0.3) !important;
}

.select2-container--default .select2-dropdown .select2-search__field {
  transition: all 150ms ease-in-out !important;
  margin-bottom: 3px !important;
  margin-top: 0 !important;
  border-radius: 3px !important;
}

.select2-container--default .select2-dropdown .select2-search__field:focus, .select2-container--default .select2-search--inline .select2-search__field:focus {
  border: 1px solid #8b8b8b !important;
  border-radius: 3px !important;
  margin-bottom: 3px !important;
  margin-top: 0 !important;
}

.select2-container--default .select2-selection--multiple .select2-selection__choice {
  background-color: #37363d !important;
  border: 1px solid rgba(161, 161, 161, 0.3) !important;
  padding: 0 0 0 20px !important;
}

.select2-selection__choice__remove {
  padding-left: 0 !important;
  border-right: 1px solid rgba(128, 128, 128, 0.3) !important;
}

.vTextField:focus-visible, .vLargeTextField:focus-visible, .vURLField:focus-visible, .vIntegerField:focus-visible, .vBigIntegerField:focus-visible, .vForeignKeyRawIdAdminField:focus-visible, .vDateField:focus-visible, .vTimeField:focus-visible, input[type=number]:focus-visible, input[type=text]:focus-visible {
  outline: none !important;
}

.vTextField, .vLargeTextField, .vURLField, .vIntegerField, .vBigIntegerField, .vForeignKeyRawIdAdminField, .vDateField, .vTimeField, input[type=number], input[type=text] {
  color: #c6c6c6 !important;
  background-color: #37363d !important;
  border: 1px solid #8b8b8b !important;
}

.select2-results__option.select2-results__option--selectable {
  color: #c6c6c6 !important;
}

.main-footer {
  margin-left: 0 !important;
}

.calendarbox {
  border: 1px solid rgba(161, 161, 161, 0.3);
  background: #454655 !important;
}

.calendar table {
  background-color: #37363d !important;
}
.calendar th {
  color: #c6c6c6 !important;
  font-weight: bold;
  background-color: #454655 !important;
  border-bottom: 1px solid rgba(161, 161, 161, 0.3) !important;
}
.calendar td.nonday {
  background-color: #454655 !important;
}
.calendar td {
  border-bottom: 1px solid rgba(161, 161, 161, 0.3) !important;
}

.calendar-shortcuts {
  background: #454655 !important;
  border-top: 0 !important;
  border-bottom: 1px solid rgba(161, 161, 161, 0.3) !important;
}

.calendar-cancel {
  background: #37363d !important;
  border-top: 0 !important;
}

.calendarnav-previous {
  top: -1px !important;
  left: -1px !important;
}

.calendarnav-next {
  top: -1px !important;
  right: -1px !important;
}

input[type=checkbox] {
  transition: all 300ms ease-in-out;
  filter: invert(0.9) hue-rotate(-180deg);
  opacity: 46%;
}
input[type=checkbox]:checked {
  filter: invert(0) hue-rotate(0deg);
  opacity: 100%;
}

ul.select2-results__options {
  -ms-overflow-style: none;
  overflow: -moz-scrollbars-none;
}
ul.select2-results__options::-webkit-scrollbar {
  width: 0;
  height: 0;
}

#result_list thead tr th .text {
  color: #e7e7e7 !important;
  white-space: nowrap;
}

.objectaction-item {
  display: flex;
  justify-content: center;
  text-align: center;
  align-items: center;
  padding: 0.3em 0.6em !important;
  margin-bottom: 1em !important;
  border-radius: 0.2em;
  background-color: rgba(161, 161, 161, 0.3);
}

.nav-sidebar .nav-item, .nav-sidebar a {
  transition: all 140ms ease-in-out !important;
}

#jazzy-actions input {
  height: fit-content;
  white-space: break-spaces;
}

.login-logo img {
  width: 100%;
}

.btn-primary {
  background-color: #fe586b;
  border-color: #fe586b;
}
.btn-primary:hover {
  background-color: #ff808e;
}

.form-control {
  color: rgba(255, 255, 255, 0.6666666667);
}
.form-control:focus {
  border-color: #ff808e;
}

.select2-selection__choice {
  background-color: rgba(0, 0, 0, 0.2) !important;
  color: #fff;
  border-radius: 0.3rem;
  padding-right: 0.5rem !important;
}
.select2-selection__choice .select2-selection__choice__remove {
  padding-right: 4px !important;
  margin-right: 0.4rem !important;
}
.select2-selection__choice:hover {
  background-color: rgba(80, 154, 255, 0.49);
}

.main-header {
  z-index: 1039 !important;
}

.main-sidebar .brand-link {
  background-color: #37363d;
}
.main-sidebar .brand-text {
  display: none !important;
}
.main-sidebar .brand-image {
  box-shadow: none !important;
  opacity: 100% !important;
}

.user-panel img {
  width: 3.3rem !important;
  height: 3.3rem !important;
  object-fit: cover;
}

.page-actions .objectaction-item {
  margin-bottom: 0 !important;
}

input#action-toggle {
  transform: scale(1.6) translateY(1px);
}

input.action-select {
  transform: scale(1.5) translateY(1px);
}

.nowrap {
  white-space: nowrap;
}

.sorting {
  white-space: nowrap;
}

@media (min-width: 800px) {
  .admin-section-nav {
    padding: 0 1rem !important;
  }
  .admin-section-content {
    padding: 1rem 1rem !important;
  }
}
@media (max-width: 799px) {
  .admin-section-nav {
    padding: 0 !important;
  }
  .admin-section-content {
    padding: 1rem 0 !important;
  }
}
.related-widget-wrapper .selector-available h2, .related-widget-wrapper .selector-chosen h2 {
  background-color: rgba(161, 161, 161, 0.3) !important;
  border-radius: 10px;
  border: none;
  color: rgba(255, 255, 255, 0.8666666667);
  font-weight: 400;
}
.related-widget-wrapper .selector-available .selector-filter, .related-widget-wrapper .selector-available .filtered, .related-widget-wrapper .selector-chosen .selector-filter, .related-widget-wrapper .selector-chosen .filtered {
  margin-top: 8px;
  background-color: rgba(161, 161, 161, 0.3) !important;
  border-radius: 10px;
  border: none;
  color: rgba(255, 255, 255, 0.8666666667);
  font-weight: 400;
}
.related-widget-wrapper .selector-available .selector-filter label, .related-widget-wrapper .selector-available .filtered label, .related-widget-wrapper .selector-chosen .selector-filter label, .related-widget-wrapper .selector-chosen .filtered label {
  display: none;
}
.related-widget-wrapper .selector-available select, .related-widget-wrapper .selector-chosen select {
  overflow-x: auto;
  -ms-overflow-style: none;
  overflow: -moz-scrollbars-none;
}
.related-widget-wrapper .selector-available select::-webkit-scrollbar, .related-widget-wrapper .selector-chosen select::-webkit-scrollbar {
  width: 0;
  height: 0;
}

@media (max-width: 767.98px) {
  .main-sidebar, .main-sidebar::before {
    margin-left: -270px !important;
  }
}
.main-header, .content-wrapper {
  margin-left: 0 !important;
}

.input-group-text {
  background-color: rgba(161, 161, 161, 0.3);
  border: 0;
}

/*# sourceMappingURL=jazzmin.css.map */
